@@ -4,7 +4,11 @@
 """
 import csv
 import os
+import re
 from typing import Text, List, Set, Dict, Union
+from faker import Faker
+
+fa = Faker('zh_CN')
 
 
 class CollUtil:
@@ -53,7 +57,7 @@ class ParameterizeUtil:
         :param headers: 表头(为空则默认取首行为表头)
         """
         with open(path) as csv_file:
-            contents = [line for line in csv_file if not line.startswith('#')]
+            contents = [ParameterizeUtil.__parse_func_all(line) for line in csv_file if not line.startswith('#')]
             if CollUtil.is_empty(headers):
                 reader = csv.DictReader(contents)
             else:
@@ -69,16 +73,59 @@ class ParameterizeUtil:
         :param ignore_first_line: 是否忽略首行
         """
         with open(path) as csv_file:
-            contents = [line for line in csv_file if not line.startswith('#')]
+            contents = [ParameterizeUtil.__parse_func_all(line) for line in csv_file if not line.startswith('#')]
             reader = csv.reader(contents)
             lines = list(reader)
         if ignore_first_line:
             del lines[0]
         return lines
 
+    @staticmethod
+    def __parse_func(expression: Text):
+        """
+        解析函数表达式
+        """
+        res = re.search(r'^\${(\w*?)(\(\))?}$', expression)
+        if not res:
+            return expression
+
+        func_str = res.group(1)
+        if not func_str or len(func_str) < 1:
+            return expression
+
+        print(f'fa.{func_str}()')
+        func_name = f'fa.{func_str}()'
+        return eval(func_name)
+
+    @staticmethod
+    def __parse_func_all(expression: Text):
+        """
+        解析函数表达式
+        """
+        pattern = r'\${(\w*?)(\(\))?}'
+        matched_list = re.findall(pattern, expression)
+
+        if not matched_list or len(matched_list) < 1:
+            return expression
+
+        matched_list = [ParameterizeUtil.__eval(e[0]) or '${%s}%s' % (e[0], e[1])for e in matched_list]
+
+        expression = re.sub(pattern=pattern, repl="{}", string=expression)
+        return expression.format(*matched_list)
+
+    @staticmethod
+    def __eval(func):
+
+        try:
+            res = eval(f'fa.{func}()')
+        except AttributeError:
+            return None
+        return res
+
 
 class FileUtil:
 
+    @staticmethod
     def locate_file(start_path: Text, file_name: Text) -> Text:
         """ locate filename and return absolute file path.
             searching will be recursive upward until system root dir.
